@@ -35,9 +35,11 @@ class Client(object):
         self.send = send
 
         if debug:
-            self.log.setLevel('DEBUG')
+            self.log.setLevel(logging.DEBUG)
 
-        self.consumer.start()
+        # if we've disabled sending, just don't start the consumer
+        if send:
+            self.consumer.start()
 
     def identify(self, user_id=None, traits={}, context={}, timestamp=None,
                  anonymous_id=None, integrations={}):
@@ -179,11 +181,8 @@ class Client(object):
             'version': VERSION
         }
 
-        clean(msg)
-
-        # if we've disabled sending, just return False
-        if not self.send:
-            return False, msg
+        msg = clean(msg)
+        self.log.debug('queueing: %s', msg)
 
         if self.queue.full():
             self.log.warn('analytics-python queue is full')
@@ -200,6 +199,12 @@ class Client(object):
         queue.join()
         self.log.debug('successfully flushed {0} items.'.format(size))
 
+    def join(self):
+        """Ends the consumer thread once the queue is empty. Blocks execution until finished"""
+        self.consumer.pause()
+        self.consumer.join()
+
+
 
 def require(name, field, data_type):
     """Require that the named `field` has the right `data_type`"""
