@@ -5,6 +5,8 @@ import numbers
 
 import six
 
+log = logging.getLogger('segment')
+
 
 def is_naive(dt):
     """Determines if a given datetime.datetime is naive."""
@@ -26,7 +28,7 @@ def guess_timezone(dt):
             # so we are in the local timezone
             return dt.replace(tzinfo=tzlocal())
         else:
-            # at this point, the best we can do (I htink) is guess UTC
+            # at this point, the best we can do is guess UTC
             return dt.replace(tzinfo=tzutc())
 
     return dt
@@ -51,18 +53,19 @@ def _clean_dict(dict_):
         try:
             data[k] = clean(v)
         except TypeError:
-            log = logging.getLogger('segment')
             log.warning('Dictionary values must be serializeable to ' +
                         'JSON "%s" value %s of type %s is unsupported.'
                         % (k, v, type(v)))
     return data
 
-def _coerce_unicode(self, cmplx):
+def _coerce_unicode(cmplx):
     try:
         item = cmplx.decode("utf-8", "strict")
     except AttributeError as exception:
         item = ":".join(exception)
         item.decode("utf-8", "strict")
+        log.warning('Error decoding: %s', item)
+        return None
     except:
         raise
     return item
\ No newline at end of file
